@@ -22,14 +22,13 @@
 #define TRAININGSESSION_H
 
 #include "artikulatecore_export.h"
-#include "course.h"
 #include "phrase.h"
+#include <QVector>
 
-class QString;
 class Language;
-class Course;
+class ICourse;
 class Unit;
-class PhonemeGroup;
+class TrainingAction;
 
 namespace LearnerProfile {
     class ProfileManager;
@@ -41,48 +40,55 @@ namespace LearnerProfile {
 class ARTIKULATECORE_EXPORT TrainingSession : public QObject
 {
     Q_OBJECT
-    Q_PROPERTY(Language *language READ language WRITE setLanguage NOTIFY languageChanged)
-    Q_PROPERTY(Course *course READ course WRITE setCourse NOTIFY courseChanged)
-    Q_PROPERTY(Unit *unit READ unit WRITE setUnit NOTIFY unitChanged)
-    Q_PROPERTY(Phrase *phrase READ phrase WRITE setPhrase NOTIFY phraseChanged)
-    Q_PROPERTY(bool hasNextPhrase READ hasNextPhrase NOTIFY phraseChanged)
+    Q_PROPERTY(ICourse *course READ course WRITE setCourse NOTIFY courseChanged)
+    Q_PROPERTY(Unit *unit READ activeUnit WRITE setUnit NOTIFY phraseChanged)
+    Q_PROPERTY(Phrase *phrase READ activePhrase WRITE setPhrase NOTIFY phraseChanged)
+    Q_PROPERTY(bool hasNext READ hasNext NOTIFY phraseChanged)
 
 public:
-    explicit TrainingSession(QObject *parent = nullptr);
+    explicit TrainingSession(LearnerProfile::ProfileManager *manager, QObject *parent = nullptr);
 
-    void setProfileManager(LearnerProfile::ProfileManager *manager);
-    Language * language() const;
-    void setLanguage(Language *language);
-    Course * course() const;
-    void setCourse(Course *course);
-    Unit * unit() const;
+    ICourse * course() const;
+    void setCourse(ICourse *course);
+    Unit * activeUnit() const;
     void setUnit(Unit *unit);
-    PhonemeGroup * phonemeGroup() const;
-    void setPhonemeGroup(PhonemeGroup *phonemeGroup);
-    Phrase::Type phraseType() const;
-    void setPhraseType(Phrase::Type type);
-    Phrase * phrase() const;
+    TrainingAction * activeAction() const;
+    Phrase * activePhrase() const;
     void setPhrase(Phrase *phrase);
-    bool hasPreviousPhrase() const;
-    bool hasNextPhrase() const;
-    Q_INVOKABLE void showNextPhrase();
-    Q_INVOKABLE void skipPhrase();
+    bool hasPrevious() const;
+    bool hasNext() const;
+    Q_INVOKABLE void accept();
+    Q_INVOKABLE void skip();
+    /**
+     * @brief Return tree of training actions
+     *
+     * The return actions form a 2-level hierarchy:
+     * - the first level are all units
+     * - the unit actions may contain sub-actions, which are the phrases
+     *
+     * @note phrases without sound file paths are skipped when generating actions
+     */
+    QVector<TrainingAction *> trainingActions() const;
 
 Q_SIGNALS:
-    void languageChanged();
     void courseChanged();
-    void unitChanged();
     void phraseChanged();
+    /**
+     * @brief Emitted when last phrase of session is skipped or marked as completed.
+     */
+    void completed();
 
-private:;
+private:
     Q_DISABLE_COPY(TrainingSession)
-    Phrase * nextPhrase() const;
+    void updateTrainingActions();
+    void selectNextPhrase();
     void updateGoal();
     LearnerProfile::ProfileManager *m_profileManager;
-    Language *m_language;
-    Course *m_course;
-    Unit *m_unit;
-    Phrase *m_phrase;
+    ICourse *m_course;
+    QVector<TrainingAction*> m_actions;
+
+    int m_indexUnit{-1};
+    int m_indexPhrase{-1};
 };
 
 #endif
